This package is a collection of diverse tools which can be useful for python based data processing for measurements obtained with Pyroscience devices/software

Parsers
-------
Parsers are included to convert logfiles to pandas.DataFrames and to extract metadata.

Oxygen Calculations
-------------------
Oxygen measurement data can be reevaluated with new/different calibrations.
Derived oxygen units (mg/L, etc) can be (re)calculated.

pH Calculations
---------------
pH values can be (re)calculated with new/different calibrations.
Drift corrections can be applied (interpolate, prospective).
